---
jupytext:
  formats: ipynb:markdown,md:myst
kernelspec:
  display_name: OCaml default
  language: OCaml
  name: ocaml-jupyter
---

# Example of an OCaml notebook

```{code-cell} OCaml
let sum x y = x + y
```

Let's try our function:

```{code-cell} OCaml
sum 3 4 = 7 + 0
```
